import React, { useEffect, useState, Suspense } from 'react';
import { useUser } from '@/contexts/UserContext';
import Navbar from '@/components/Navbar';
import Footer from '@/components/Footer';
import { useToast } from "@/hooks/use-toast";
import { useInternships } from "@/hooks/useInternships";
import { Spinner } from "@/components/ui/spinner";
import InternshipProcessWidget from "@/components/InternshipProcessWidget";
import { useNavigate } from "react-router-dom";
import type { Internship } from "@/lib/data";

// Home section components
import HeroSection from "@/components/home/HeroSection";
import FeaturedInternshipsSection from "@/components/home/FeaturedInternshipsSection";
import LatestInternshipsSection from "@/components/home/LatestInternshipsSection";
import FeaturedTalentsSection from "@/components/home/FeaturedTalentsSection";
import HireAITalentCTA from "@/components/home/HireAITalentCTA";

// Lazy load below-the-fold components
const SwipeFeatureWidget = React.lazy(() => import('@/components/SwipeFeatureWidget'));
const PricingWidget = React.lazy(() => import('@/components/PricingWidget'));
const BlogWidget = React.lazy(() => import('@/components/BlogWidget'));
const FAQWidget = React.lazy(() => import('@/components/FAQWidget'));

const LazyWidgetFallback = () => (
  <div className="flex justify-center py-8">
    <Spinner size="md" />
  </div>
);

const Index: React.FC = () => {
  const { user } = useUser();
  const { toast } = useToast();
  const navigate = useNavigate();
  
  // Fetch featured internships directly from Supabase
  const { 
    internships: featuredInternships, 
    loading: loadingFeatured, 
    error: featuredError
  } = useInternships({ featured: true, limit: 3 });
  
  // Fetch all internships (limited to 5 for Latest Added section)
  const { 
    internships: allInternships, 
    loading: loadingAll, 
    error: allError 
  } = useInternships({ limit: 5 });
  
  // Fetch talent profiles
  const [talentProfiles, setTalentProfiles] = useState<any[]>([]);
  const [loadingTalent, setLoadingTalent] = useState(true);
  
  useEffect(() => {
    // Fetch talent profiles from Supabase
    const fetchTalentProfiles = async () => {
      try {
        const { supabase } = await import('@/lib/supabase');
        const { data, error } = await supabase
          .from('talent_profiles')
          .select('*')
          .limit(3);
        
        if (error) {
          throw error;
        }
        
        if (data) {
          setTalentProfiles(data);
        }
      } catch (error) {
        console.error('Error fetching talent profiles:', error);
      } finally {
        setLoadingTalent(false);
      }
    };
    
    fetchTalentProfiles();
  }, []);

  useEffect(() => {
    if (featuredError || allError) {
      toast({
        title: "Error",
        description: "Failed to load internship listings.",
        variant: "destructive",
      });
    }
  }, [featuredError, allError, toast]);
  
  const handleSearch = (query: string, location: string) => {
    let searchParams = new URLSearchParams();
    if (query) searchParams.set("q", query);
    if (location) searchParams.set("location", location);
    navigate(`/find-ai-internships?${searchParams.toString()}`);
  };

  // Function to handle search tag clicks
  const handleSearchTagClick = (query: string = '', location: string = '') => {
    let searchParams = new URLSearchParams();
    if (query) searchParams.set("q", query);
    if (location) searchParams.set("location", location);
    navigate(`/find-ai-internships?${searchParams.toString()}`);
  };

  // Function to handle Post Internship button click with proper redirection based on user type
  const handlePostInternshipClick = () => {
    if (!user) {
      // Not logged in, redirect to auth page
      navigate('/auth');
      return;
    }
    
    if (user.userType === 'employer' || user.userType === 'admin') {
      // Employer or admin, redirect to post internship page
      navigate('/post-internship');
      return;
    }
    
    // Internship seeker, show notification
    toast({
      title: "Employers Only",
      description: "Only employers can post internship opportunities",
      variant: "destructive",
    });
  };

  return (
    <div className="flex flex-col min-h-screen">
      <Navbar />
      
      {/* 1. SEARCH SECTION with Purple Gradient Background */}
      <HeroSection 
        onSearch={handleSearch}
        onSearchTagClick={handleSearchTagClick}
      />

      {/* 2. FEATURED INTERNSHIPS SECTION */}
      <FeaturedInternshipsSection 
        internships={featuredInternships}
        loading={loadingFeatured}
      />
      
      {/* 3. LATEST ADDED AI INTERNSHIPS */}
      <LatestInternshipsSection 
        internships={allInternships}
        loading={loadingAll}
      />

      {/* 4. REVOLUTIONIZING YOUR AI CAREER JOURNEY */}
      <InternshipProcessWidget />

      {/* 5. FEATURED AI TALENTS SECTION */}
      <FeaturedTalentsSection 
        talentProfiles={talentProfiles}
        loading={loadingTalent}
      />
      
      {/* 6. SWIPE FEATURE - Lazy loaded */}
      <Suspense fallback={<LazyWidgetFallback />}>
        <SwipeFeatureWidget />
      </Suspense>
      
      {/* 7. PRICING WIDGET - Lazy loaded */}
      <Suspense fallback={<LazyWidgetFallback />}>
        <PricingWidget />
      </Suspense>
      
      {/* 8. BLOG WIDGET - Lazy loaded */}
      <Suspense fallback={<LazyWidgetFallback />}>
        <BlogWidget />
      </Suspense>
      
      {/* 9. FAQ WIDGET - Lazy loaded */}
      <Suspense fallback={<LazyWidgetFallback />}>
        <FAQWidget />
      </Suspense>
      
      {/* 10. HIRE AI TALENT CTA SECTION */}
      <HireAITalentCTA onPostInternshipClick={handlePostInternshipClick} />

      <Footer />
    </div>
  );
};

export default Index;
